
package org.mule.modules.vertex.config.spring;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.modules.vertex.config.CalculateBuyerInputTaxMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.support.ManagedMap;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.xml.DomUtils;
import org.w3c.dom.Element;

public class CalculateBuyerInputTaxDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public CalculateBuyerInputTaxDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(CalculateBuyerInputTaxMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        Element currencyListElement = null;
        currencyListElement = DomUtils.getChildElementByTagName(element, "currency");
        List<Element> currencyListChilds = null;
        if (currencyListElement!= null) {
            String currencyRef = currencyListElement.getAttribute("ref");
            if ((currencyRef!= null)&&(!StringUtils.isBlank(currencyRef))) {
                if ((!currencyRef.startsWith(patternInfo.getPrefix()))&&(!currencyRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("currency", new RuntimeBeanReference(currencyRef));
                } else {
                    builder.addPropertyValue("currency", currencyRef);
                }
            } else {
                ManagedMap currency = new ManagedMap();
                currencyListChilds = DomUtils.getChildElementsByTagName(currencyListElement, "currency");
                if (currencyListChilds!= null) {
                    if (currencyListChilds.size() == 0) {
                        currencyListChilds = DomUtils.getChildElements(currencyListElement);
                    }
                    for (Element currencyChild: currencyListChilds) {
                        String currencyValueRef = currencyChild.getAttribute("value-ref");
                        String currencyKeyRef = currencyChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((currencyValueRef!= null)&&(!StringUtils.isBlank(currencyValueRef))) {
                            valueObject = new RuntimeBeanReference(currencyValueRef);
                        } else {
                            valueObject = currencyChild.getTextContent();
                        }
                        if ((currencyKeyRef!= null)&&(!StringUtils.isBlank(currencyKeyRef))) {
                            keyObject = new RuntimeBeanReference(currencyKeyRef);
                        } else {
                            keyObject = currencyChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = currencyChild.getTagName();
                        }
                        currency.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("currency", currency);
            }
        }
        Element originalCurrencyListElement = null;
        originalCurrencyListElement = DomUtils.getChildElementByTagName(element, "original-currency");
        List<Element> originalCurrencyListChilds = null;
        if (originalCurrencyListElement!= null) {
            String originalCurrencyRef = originalCurrencyListElement.getAttribute("ref");
            if ((originalCurrencyRef!= null)&&(!StringUtils.isBlank(originalCurrencyRef))) {
                if ((!originalCurrencyRef.startsWith(patternInfo.getPrefix()))&&(!originalCurrencyRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("originalCurrency", new RuntimeBeanReference(originalCurrencyRef));
                } else {
                    builder.addPropertyValue("originalCurrency", originalCurrencyRef);
                }
            } else {
                ManagedMap originalCurrency = new ManagedMap();
                originalCurrencyListChilds = DomUtils.getChildElementsByTagName(originalCurrencyListElement, "original-currency");
                if (originalCurrencyListChilds!= null) {
                    if (originalCurrencyListChilds.size() == 0) {
                        originalCurrencyListChilds = DomUtils.getChildElements(originalCurrencyListElement);
                    }
                    for (Element originalCurrencyChild: originalCurrencyListChilds) {
                        String originalCurrencyValueRef = originalCurrencyChild.getAttribute("value-ref");
                        String originalCurrencyKeyRef = originalCurrencyChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((originalCurrencyValueRef!= null)&&(!StringUtils.isBlank(originalCurrencyValueRef))) {
                            valueObject = new RuntimeBeanReference(originalCurrencyValueRef);
                        } else {
                            valueObject = originalCurrencyChild.getTextContent();
                        }
                        if ((originalCurrencyKeyRef!= null)&&(!StringUtils.isBlank(originalCurrencyKeyRef))) {
                            keyObject = new RuntimeBeanReference(originalCurrencyKeyRef);
                        } else {
                            keyObject = originalCurrencyChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = originalCurrencyChild.getTagName();
                        }
                        originalCurrency.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("originalCurrency", originalCurrency);
            }
        }
        Element buyerListElement = null;
        buyerListElement = DomUtils.getChildElementByTagName(element, "buyer");
        List<Element> buyerListChilds = null;
        if (buyerListElement!= null) {
            String buyerRef = buyerListElement.getAttribute("ref");
            if ((buyerRef!= null)&&(!StringUtils.isBlank(buyerRef))) {
                if ((!buyerRef.startsWith(patternInfo.getPrefix()))&&(!buyerRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("buyer", new RuntimeBeanReference(buyerRef));
                } else {
                    builder.addPropertyValue("buyer", buyerRef);
                }
            } else {
                ManagedMap buyer = new ManagedMap();
                buyerListChilds = DomUtils.getChildElementsByTagName(buyerListElement, "buyer");
                if (buyerListChilds!= null) {
                    if (buyerListChilds.size() == 0) {
                        buyerListChilds = DomUtils.getChildElements(buyerListElement);
                    }
                    for (Element buyerChild: buyerListChilds) {
                        String buyerValueRef = buyerChild.getAttribute("value-ref");
                        String buyerKeyRef = buyerChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((buyerValueRef!= null)&&(!StringUtils.isBlank(buyerValueRef))) {
                            valueObject = new RuntimeBeanReference(buyerValueRef);
                        } else {
                            valueObject = buyerChild.getTextContent();
                        }
                        if ((buyerKeyRef!= null)&&(!StringUtils.isBlank(buyerKeyRef))) {
                            keyObject = new RuntimeBeanReference(buyerKeyRef);
                        } else {
                            keyObject = buyerChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = buyerChild.getTagName();
                        }
                        buyer.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("buyer", buyer);
            }
        }
        Element vendorListElement = null;
        vendorListElement = DomUtils.getChildElementByTagName(element, "vendor");
        List<Element> vendorListChilds = null;
        if (vendorListElement!= null) {
            String vendorRef = vendorListElement.getAttribute("ref");
            if ((vendorRef!= null)&&(!StringUtils.isBlank(vendorRef))) {
                if ((!vendorRef.startsWith(patternInfo.getPrefix()))&&(!vendorRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("vendor", new RuntimeBeanReference(vendorRef));
                } else {
                    builder.addPropertyValue("vendor", vendorRef);
                }
            } else {
                ManagedMap vendor = new ManagedMap();
                vendorListChilds = DomUtils.getChildElementsByTagName(vendorListElement, "vendor");
                if (vendorListChilds!= null) {
                    if (vendorListChilds.size() == 0) {
                        vendorListChilds = DomUtils.getChildElements(vendorListElement);
                    }
                    for (Element vendorChild: vendorListChilds) {
                        String vendorValueRef = vendorChild.getAttribute("value-ref");
                        String vendorKeyRef = vendorChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((vendorValueRef!= null)&&(!StringUtils.isBlank(vendorValueRef))) {
                            valueObject = new RuntimeBeanReference(vendorValueRef);
                        } else {
                            valueObject = vendorChild.getTextContent();
                        }
                        if ((vendorKeyRef!= null)&&(!StringUtils.isBlank(vendorKeyRef))) {
                            keyObject = new RuntimeBeanReference(vendorKeyRef);
                        } else {
                            keyObject = vendorChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = vendorChild.getTagName();
                        }
                        vendor.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("vendor", vendor);
            }
        }
        Element lineItemsListElement = null;
        lineItemsListElement = DomUtils.getChildElementByTagName(element, "line-items");
        List<Element> lineItemsListChilds = null;
        if (lineItemsListElement!= null) {
            String lineItemsRef = lineItemsListElement.getAttribute("ref");
            if ((lineItemsRef!= null)&&(!StringUtils.isBlank(lineItemsRef))) {
                if ((!lineItemsRef.startsWith(patternInfo.getPrefix()))&&(!lineItemsRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("lineItems", new RuntimeBeanReference(lineItemsRef));
                } else {
                    builder.addPropertyValue("lineItems", lineItemsRef);
                }
            } else {
                ManagedList lineItems = new ManagedList();
                lineItemsListChilds = DomUtils.getChildElementsByTagName(lineItemsListElement, "line-item");
                if (lineItemsListChilds!= null) {
                    for (Element lineItemsChild: lineItemsListChilds) {
                        String valueRef = lineItemsChild.getAttribute("value-ref");
                        if ((valueRef!= null)&&(!StringUtils.isBlank(valueRef))) {
                            lineItems.add(new RuntimeBeanReference(valueRef));
                        } else {
                            List<Element> innerlineitemListChilds = null;
                            if (lineItemsChild!= null) {
                                String innerlineitemRef = lineItemsChild.getAttribute("ref");
                                if ((innerlineitemRef!= null)&&(!StringUtils.isBlank(innerlineitemRef))) {
                                    if ((!innerlineitemRef.startsWith(patternInfo.getPrefix()))&&(!innerlineitemRef.endsWith(patternInfo.getSuffix()))) {
                                        builder.addPropertyValue("inner-line-item", new RuntimeBeanReference(innerlineitemRef));
                                    } else {
                                        builder.addPropertyValue("inner-line-item", innerlineitemRef);
                                    }
                                } else {
                                    ManagedMap innerlineitem = new ManagedMap();
                                    innerlineitemListChilds = DomUtils.getChildElementsByTagName(lineItemsChild, "inner-line-item");
                                    if (innerlineitemListChilds!= null) {
                                        if (innerlineitemListChilds.size() == 0) {
                                            innerlineitemListChilds = DomUtils.getChildElements(lineItemsChild);
                                        }
                                        for (Element innerlineitemChild: innerlineitemListChilds) {
                                            String innerlineitemValueRef = innerlineitemChild.getAttribute("value-ref");
                                            String innerlineitemKeyRef = innerlineitemChild.getAttribute("key-ref");
                                            Object valueObject = null;
                                            Object keyObject = null;
                                            if ((innerlineitemValueRef!= null)&&(!StringUtils.isBlank(innerlineitemValueRef))) {
                                                valueObject = new RuntimeBeanReference(innerlineitemValueRef);
                                            } else {
                                                valueObject = innerlineitemChild.getTextContent();
                                            }
                                            if ((innerlineitemKeyRef!= null)&&(!StringUtils.isBlank(innerlineitemKeyRef))) {
                                                keyObject = new RuntimeBeanReference(innerlineitemKeyRef);
                                            } else {
                                                keyObject = innerlineitemChild.getAttribute("key");
                                            }
                                            if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                                                keyObject = innerlineitemChild.getTagName();
                                            }
                                            innerlineitem.put(keyObject, valueObject);
                                        }
                                    }
                                    lineItems.add(innerlineitem);
                                }
                            }
                        }
                    }
                }
                builder.addPropertyValue("lineItems", lineItems);
            }
        }
        if ((element.getAttribute("documentNumber")!= null)&&(!StringUtils.isBlank(element.getAttribute("documentNumber")))) {
            builder.addPropertyValue("documentNumber", element.getAttribute("documentNumber"));
        }
        if ((element.getAttribute("postingDate")!= null)&&(!StringUtils.isBlank(element.getAttribute("postingDate")))) {
            builder.addPropertyValue("postingDate", element.getAttribute("postingDate"));
        }
        if ((element.getAttribute("locationCode")!= null)&&(!StringUtils.isBlank(element.getAttribute("locationCode")))) {
            builder.addPropertyValue("locationCode", element.getAttribute("locationCode"));
        }
        if ((element.getAttribute("returnAssistedParametersIndicator")!= null)&&(!StringUtils.isBlank(element.getAttribute("returnAssistedParametersIndicator")))) {
            builder.addPropertyValue("returnAssistedParametersIndicator", element.getAttribute("returnAssistedParametersIndicator"));
        }
        if ((element.getAttribute("returnGeneratedLineItemsIndicator")!= null)&&(!StringUtils.isBlank(element.getAttribute("returnGeneratedLineItemsIndicator")))) {
            builder.addPropertyValue("returnGeneratedLineItemsIndicator", element.getAttribute("returnGeneratedLineItemsIndicator"));
        }
        if (element.hasAttribute("deliveryTerm")) {
            builder.addPropertyValue("deliveryTerm", element.getAttribute("deliveryTerm"));
        }
        if ((element.getAttribute("documentDate")!= null)&&(!StringUtils.isBlank(element.getAttribute("documentDate")))) {
            builder.addPropertyValue("documentDate", element.getAttribute("documentDate"));
        }
        if ((element.getAttribute("transactionId")!= null)&&(!StringUtils.isBlank(element.getAttribute("transactionId")))) {
            builder.addPropertyValue("transactionId", element.getAttribute("transactionId"));
        }
        if ((element.getAttribute("recoverableDate")!= null)&&(!StringUtils.isBlank(element.getAttribute("recoverableDate")))) {
            builder.addPropertyValue("recoverableDate", element.getAttribute("recoverableDate"));
        }
        if ((element.getAttribute("postToJournal")!= null)&&(!StringUtils.isBlank(element.getAttribute("postToJournal")))) {
            builder.addPropertyValue("postToJournal", element.getAttribute("postToJournal"));
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
