
package org.mule.modules.vertex.config.spring;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.modules.vertex.config.CalculateInventoryRemovalTaxMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.support.ManagedMap;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.xml.DomUtils;
import org.w3c.dom.Element;

public class CalculateInventoryRemovalTaxDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public CalculateInventoryRemovalTaxDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(CalculateInventoryRemovalTaxMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        Element currencyListElement = null;
        currencyListElement = DomUtils.getChildElementByTagName(element, "currency");
        List<Element> currencyListChilds = null;
        if (currencyListElement!= null) {
            String currencyRef = currencyListElement.getAttribute("ref");
            if ((currencyRef!= null)&&(!StringUtils.isBlank(currencyRef))) {
                if ((!currencyRef.startsWith(patternInfo.getPrefix()))&&(!currencyRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("currency", new RuntimeBeanReference(currencyRef));
                } else {
                    builder.addPropertyValue("currency", currencyRef);
                }
            } else {
                ManagedMap currency = new ManagedMap();
                currencyListChilds = DomUtils.getChildElementsByTagName(currencyListElement, "currency");
                if (currencyListChilds!= null) {
                    if (currencyListChilds.size() == 0) {
                        currencyListChilds = DomUtils.getChildElements(currencyListElement);
                    }
                    for (Element currencyChild: currencyListChilds) {
                        String currencyValueRef = currencyChild.getAttribute("value-ref");
                        String currencyKeyRef = currencyChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((currencyValueRef!= null)&&(!StringUtils.isBlank(currencyValueRef))) {
                            valueObject = new RuntimeBeanReference(currencyValueRef);
                        } else {
                            valueObject = currencyChild.getTextContent();
                        }
                        if ((currencyKeyRef!= null)&&(!StringUtils.isBlank(currencyKeyRef))) {
                            keyObject = new RuntimeBeanReference(currencyKeyRef);
                        } else {
                            keyObject = currencyChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = currencyChild.getTagName();
                        }
                        currency.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("currency", currency);
            }
        }
        Element originalCurrencyListElement = null;
        originalCurrencyListElement = DomUtils.getChildElementByTagName(element, "original-currency");
        List<Element> originalCurrencyListChilds = null;
        if (originalCurrencyListElement!= null) {
            String originalCurrencyRef = originalCurrencyListElement.getAttribute("ref");
            if ((originalCurrencyRef!= null)&&(!StringUtils.isBlank(originalCurrencyRef))) {
                if ((!originalCurrencyRef.startsWith(patternInfo.getPrefix()))&&(!originalCurrencyRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("originalCurrency", new RuntimeBeanReference(originalCurrencyRef));
                } else {
                    builder.addPropertyValue("originalCurrency", originalCurrencyRef);
                }
            } else {
                ManagedMap originalCurrency = new ManagedMap();
                originalCurrencyListChilds = DomUtils.getChildElementsByTagName(originalCurrencyListElement, "original-currency");
                if (originalCurrencyListChilds!= null) {
                    if (originalCurrencyListChilds.size() == 0) {
                        originalCurrencyListChilds = DomUtils.getChildElements(originalCurrencyListElement);
                    }
                    for (Element originalCurrencyChild: originalCurrencyListChilds) {
                        String originalCurrencyValueRef = originalCurrencyChild.getAttribute("value-ref");
                        String originalCurrencyKeyRef = originalCurrencyChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((originalCurrencyValueRef!= null)&&(!StringUtils.isBlank(originalCurrencyValueRef))) {
                            valueObject = new RuntimeBeanReference(originalCurrencyValueRef);
                        } else {
                            valueObject = originalCurrencyChild.getTextContent();
                        }
                        if ((originalCurrencyKeyRef!= null)&&(!StringUtils.isBlank(originalCurrencyKeyRef))) {
                            keyObject = new RuntimeBeanReference(originalCurrencyKeyRef);
                        } else {
                            keyObject = originalCurrencyChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = originalCurrencyChild.getTagName();
                        }
                        originalCurrency.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("originalCurrency", originalCurrency);
            }
        }
        Element ownerListElement = null;
        ownerListElement = DomUtils.getChildElementByTagName(element, "owner");
        List<Element> ownerListChilds = null;
        if (ownerListElement!= null) {
            String ownerRef = ownerListElement.getAttribute("ref");
            if ((ownerRef!= null)&&(!StringUtils.isBlank(ownerRef))) {
                if ((!ownerRef.startsWith(patternInfo.getPrefix()))&&(!ownerRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("owner", new RuntimeBeanReference(ownerRef));
                } else {
                    builder.addPropertyValue("owner", ownerRef);
                }
            } else {
                ManagedMap owner = new ManagedMap();
                ownerListChilds = DomUtils.getChildElementsByTagName(ownerListElement, "owner");
                if (ownerListChilds!= null) {
                    if (ownerListChilds.size() == 0) {
                        ownerListChilds = DomUtils.getChildElements(ownerListElement);
                    }
                    for (Element ownerChild: ownerListChilds) {
                        String ownerValueRef = ownerChild.getAttribute("value-ref");
                        String ownerKeyRef = ownerChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((ownerValueRef!= null)&&(!StringUtils.isBlank(ownerValueRef))) {
                            valueObject = new RuntimeBeanReference(ownerValueRef);
                        } else {
                            valueObject = ownerChild.getTextContent();
                        }
                        if ((ownerKeyRef!= null)&&(!StringUtils.isBlank(ownerKeyRef))) {
                            keyObject = new RuntimeBeanReference(ownerKeyRef);
                        } else {
                            keyObject = ownerChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = ownerChild.getTagName();
                        }
                        owner.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("owner", owner);
            }
        }
        Element taxOverrideListElement = null;
        taxOverrideListElement = DomUtils.getChildElementByTagName(element, "tax-override");
        List<Element> taxOverrideListChilds = null;
        if (taxOverrideListElement!= null) {
            String taxOverrideRef = taxOverrideListElement.getAttribute("ref");
            if ((taxOverrideRef!= null)&&(!StringUtils.isBlank(taxOverrideRef))) {
                if ((!taxOverrideRef.startsWith(patternInfo.getPrefix()))&&(!taxOverrideRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("taxOverride", new RuntimeBeanReference(taxOverrideRef));
                } else {
                    builder.addPropertyValue("taxOverride", taxOverrideRef);
                }
            } else {
                ManagedMap taxOverride = new ManagedMap();
                taxOverrideListChilds = DomUtils.getChildElementsByTagName(taxOverrideListElement, "tax-override");
                if (taxOverrideListChilds!= null) {
                    if (taxOverrideListChilds.size() == 0) {
                        taxOverrideListChilds = DomUtils.getChildElements(taxOverrideListElement);
                    }
                    for (Element taxOverrideChild: taxOverrideListChilds) {
                        String taxOverrideValueRef = taxOverrideChild.getAttribute("value-ref");
                        String taxOverrideKeyRef = taxOverrideChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((taxOverrideValueRef!= null)&&(!StringUtils.isBlank(taxOverrideValueRef))) {
                            valueObject = new RuntimeBeanReference(taxOverrideValueRef);
                        } else {
                            valueObject = taxOverrideChild.getTextContent();
                        }
                        if ((taxOverrideKeyRef!= null)&&(!StringUtils.isBlank(taxOverrideKeyRef))) {
                            keyObject = new RuntimeBeanReference(taxOverrideKeyRef);
                        } else {
                            keyObject = taxOverrideChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = taxOverrideChild.getTagName();
                        }
                        taxOverride.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("taxOverride", taxOverride);
            }
        }
        Element impositionsToProcessListElement = null;
        impositionsToProcessListElement = DomUtils.getChildElementByTagName(element, "impositions-to-process");
        List<Element> impositionsToProcessListChilds = null;
        if (impositionsToProcessListElement!= null) {
            String impositionsToProcessRef = impositionsToProcessListElement.getAttribute("ref");
            if ((impositionsToProcessRef!= null)&&(!StringUtils.isBlank(impositionsToProcessRef))) {
                if ((!impositionsToProcessRef.startsWith(patternInfo.getPrefix()))&&(!impositionsToProcessRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("impositionsToProcess", new RuntimeBeanReference(impositionsToProcessRef));
                } else {
                    builder.addPropertyValue("impositionsToProcess", impositionsToProcessRef);
                }
            } else {
                ManagedList impositionsToProcess = new ManagedList();
                impositionsToProcessListChilds = DomUtils.getChildElementsByTagName(impositionsToProcessListElement, "impositions-to-proces");
                if (impositionsToProcessListChilds!= null) {
                    for (Element impositionsToProcessChild: impositionsToProcessListChilds) {
                        String valueRef = impositionsToProcessChild.getAttribute("value-ref");
                        if ((valueRef!= null)&&(!StringUtils.isBlank(valueRef))) {
                            impositionsToProcess.add(new RuntimeBeanReference(valueRef));
                        } else {
                            List<Element> innerimpositionstoprocesListChilds = null;
                            if (impositionsToProcessChild!= null) {
                                String innerimpositionstoprocesRef = impositionsToProcessChild.getAttribute("ref");
                                if ((innerimpositionstoprocesRef!= null)&&(!StringUtils.isBlank(innerimpositionstoprocesRef))) {
                                    if ((!innerimpositionstoprocesRef.startsWith(patternInfo.getPrefix()))&&(!innerimpositionstoprocesRef.endsWith(patternInfo.getSuffix()))) {
                                        builder.addPropertyValue("inner-impositions-to-proces", new RuntimeBeanReference(innerimpositionstoprocesRef));
                                    } else {
                                        builder.addPropertyValue("inner-impositions-to-proces", innerimpositionstoprocesRef);
                                    }
                                } else {
                                    ManagedMap innerimpositionstoproces = new ManagedMap();
                                    innerimpositionstoprocesListChilds = DomUtils.getChildElementsByTagName(impositionsToProcessChild, "inner-impositions-to-proce");
                                    if (innerimpositionstoprocesListChilds!= null) {
                                        if (innerimpositionstoprocesListChilds.size() == 0) {
                                            innerimpositionstoprocesListChilds = DomUtils.getChildElements(impositionsToProcessChild);
                                        }
                                        for (Element innerimpositionstoprocesChild: innerimpositionstoprocesListChilds) {
                                            String innerimpositionstoprocesValueRef = innerimpositionstoprocesChild.getAttribute("value-ref");
                                            String innerimpositionstoprocesKeyRef = innerimpositionstoprocesChild.getAttribute("key-ref");
                                            Object valueObject = null;
                                            Object keyObject = null;
                                            if ((innerimpositionstoprocesValueRef!= null)&&(!StringUtils.isBlank(innerimpositionstoprocesValueRef))) {
                                                valueObject = new RuntimeBeanReference(innerimpositionstoprocesValueRef);
                                            } else {
                                                valueObject = innerimpositionstoprocesChild.getTextContent();
                                            }
                                            if ((innerimpositionstoprocesKeyRef!= null)&&(!StringUtils.isBlank(innerimpositionstoprocesKeyRef))) {
                                                keyObject = new RuntimeBeanReference(innerimpositionstoprocesKeyRef);
                                            } else {
                                                keyObject = innerimpositionstoprocesChild.getAttribute("key");
                                            }
                                            if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                                                keyObject = innerimpositionstoprocesChild.getTagName();
                                            }
                                            innerimpositionstoproces.put(keyObject, valueObject);
                                        }
                                    }
                                    impositionsToProcess.add(innerimpositionstoproces);
                                }
                            }
                        }
                    }
                }
                builder.addPropertyValue("impositionsToProcess", impositionsToProcess);
            }
        }
        Element jurisdictionOverridesListElement = null;
        jurisdictionOverridesListElement = DomUtils.getChildElementByTagName(element, "jurisdiction-overrides");
        List<Element> jurisdictionOverridesListChilds = null;
        if (jurisdictionOverridesListElement!= null) {
            String jurisdictionOverridesRef = jurisdictionOverridesListElement.getAttribute("ref");
            if ((jurisdictionOverridesRef!= null)&&(!StringUtils.isBlank(jurisdictionOverridesRef))) {
                if ((!jurisdictionOverridesRef.startsWith(patternInfo.getPrefix()))&&(!jurisdictionOverridesRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("jurisdictionOverrides", new RuntimeBeanReference(jurisdictionOverridesRef));
                } else {
                    builder.addPropertyValue("jurisdictionOverrides", jurisdictionOverridesRef);
                }
            } else {
                ManagedList jurisdictionOverrides = new ManagedList();
                jurisdictionOverridesListChilds = DomUtils.getChildElementsByTagName(jurisdictionOverridesListElement, "jurisdiction-override");
                if (jurisdictionOverridesListChilds!= null) {
                    for (Element jurisdictionOverridesChild: jurisdictionOverridesListChilds) {
                        String valueRef = jurisdictionOverridesChild.getAttribute("value-ref");
                        if ((valueRef!= null)&&(!StringUtils.isBlank(valueRef))) {
                            jurisdictionOverrides.add(new RuntimeBeanReference(valueRef));
                        } else {
                            List<Element> innerjurisdictionoverrideListChilds = null;
                            if (jurisdictionOverridesChild!= null) {
                                String innerjurisdictionoverrideRef = jurisdictionOverridesChild.getAttribute("ref");
                                if ((innerjurisdictionoverrideRef!= null)&&(!StringUtils.isBlank(innerjurisdictionoverrideRef))) {
                                    if ((!innerjurisdictionoverrideRef.startsWith(patternInfo.getPrefix()))&&(!innerjurisdictionoverrideRef.endsWith(patternInfo.getSuffix()))) {
                                        builder.addPropertyValue("inner-jurisdiction-override", new RuntimeBeanReference(innerjurisdictionoverrideRef));
                                    } else {
                                        builder.addPropertyValue("inner-jurisdiction-override", innerjurisdictionoverrideRef);
                                    }
                                } else {
                                    ManagedMap innerjurisdictionoverride = new ManagedMap();
                                    innerjurisdictionoverrideListChilds = DomUtils.getChildElementsByTagName(jurisdictionOverridesChild, "inner-jurisdiction-override");
                                    if (innerjurisdictionoverrideListChilds!= null) {
                                        if (innerjurisdictionoverrideListChilds.size() == 0) {
                                            innerjurisdictionoverrideListChilds = DomUtils.getChildElements(jurisdictionOverridesChild);
                                        }
                                        for (Element innerjurisdictionoverrideChild: innerjurisdictionoverrideListChilds) {
                                            String innerjurisdictionoverrideValueRef = innerjurisdictionoverrideChild.getAttribute("value-ref");
                                            String innerjurisdictionoverrideKeyRef = innerjurisdictionoverrideChild.getAttribute("key-ref");
                                            Object valueObject = null;
                                            Object keyObject = null;
                                            if ((innerjurisdictionoverrideValueRef!= null)&&(!StringUtils.isBlank(innerjurisdictionoverrideValueRef))) {
                                                valueObject = new RuntimeBeanReference(innerjurisdictionoverrideValueRef);
                                            } else {
                                                valueObject = innerjurisdictionoverrideChild.getTextContent();
                                            }
                                            if ((innerjurisdictionoverrideKeyRef!= null)&&(!StringUtils.isBlank(innerjurisdictionoverrideKeyRef))) {
                                                keyObject = new RuntimeBeanReference(innerjurisdictionoverrideKeyRef);
                                            } else {
                                                keyObject = innerjurisdictionoverrideChild.getAttribute("key");
                                            }
                                            if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                                                keyObject = innerjurisdictionoverrideChild.getTagName();
                                            }
                                            innerjurisdictionoverride.put(keyObject, valueObject);
                                        }
                                    }
                                    jurisdictionOverrides.add(innerjurisdictionoverride);
                                }
                            }
                        }
                    }
                }
                builder.addPropertyValue("jurisdictionOverrides", jurisdictionOverrides);
            }
        }
        Element situsOverrideListElement = null;
        situsOverrideListElement = DomUtils.getChildElementByTagName(element, "situs-override");
        List<Element> situsOverrideListChilds = null;
        if (situsOverrideListElement!= null) {
            String situsOverrideRef = situsOverrideListElement.getAttribute("ref");
            if ((situsOverrideRef!= null)&&(!StringUtils.isBlank(situsOverrideRef))) {
                if ((!situsOverrideRef.startsWith(patternInfo.getPrefix()))&&(!situsOverrideRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("situsOverride", new RuntimeBeanReference(situsOverrideRef));
                } else {
                    builder.addPropertyValue("situsOverride", situsOverrideRef);
                }
            } else {
                ManagedMap situsOverride = new ManagedMap();
                situsOverrideListChilds = DomUtils.getChildElementsByTagName(situsOverrideListElement, "situs-override");
                if (situsOverrideListChilds!= null) {
                    if (situsOverrideListChilds.size() == 0) {
                        situsOverrideListChilds = DomUtils.getChildElements(situsOverrideListElement);
                    }
                    for (Element situsOverrideChild: situsOverrideListChilds) {
                        String situsOverrideValueRef = situsOverrideChild.getAttribute("value-ref");
                        String situsOverrideKeyRef = situsOverrideChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((situsOverrideValueRef!= null)&&(!StringUtils.isBlank(situsOverrideValueRef))) {
                            valueObject = new RuntimeBeanReference(situsOverrideValueRef);
                        } else {
                            valueObject = situsOverrideChild.getTextContent();
                        }
                        if ((situsOverrideKeyRef!= null)&&(!StringUtils.isBlank(situsOverrideKeyRef))) {
                            keyObject = new RuntimeBeanReference(situsOverrideKeyRef);
                        } else {
                            keyObject = situsOverrideChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = situsOverrideChild.getTagName();
                        }
                        situsOverride.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("situsOverride", situsOverride);
            }
        }
        Element lineItemsListElement = null;
        lineItemsListElement = DomUtils.getChildElementByTagName(element, "line-items");
        List<Element> lineItemsListChilds = null;
        if (lineItemsListElement!= null) {
            String lineItemsRef = lineItemsListElement.getAttribute("ref");
            if ((lineItemsRef!= null)&&(!StringUtils.isBlank(lineItemsRef))) {
                if ((!lineItemsRef.startsWith(patternInfo.getPrefix()))&&(!lineItemsRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("lineItems", new RuntimeBeanReference(lineItemsRef));
                } else {
                    builder.addPropertyValue("lineItems", lineItemsRef);
                }
            } else {
                ManagedList lineItems = new ManagedList();
                lineItemsListChilds = DomUtils.getChildElementsByTagName(lineItemsListElement, "line-item");
                if (lineItemsListChilds!= null) {
                    for (Element lineItemsChild: lineItemsListChilds) {
                        String valueRef = lineItemsChild.getAttribute("value-ref");
                        if ((valueRef!= null)&&(!StringUtils.isBlank(valueRef))) {
                            lineItems.add(new RuntimeBeanReference(valueRef));
                        } else {
                            List<Element> innerlineitemListChilds = null;
                            if (lineItemsChild!= null) {
                                String innerlineitemRef = lineItemsChild.getAttribute("ref");
                                if ((innerlineitemRef!= null)&&(!StringUtils.isBlank(innerlineitemRef))) {
                                    if ((!innerlineitemRef.startsWith(patternInfo.getPrefix()))&&(!innerlineitemRef.endsWith(patternInfo.getSuffix()))) {
                                        builder.addPropertyValue("inner-line-item", new RuntimeBeanReference(innerlineitemRef));
                                    } else {
                                        builder.addPropertyValue("inner-line-item", innerlineitemRef);
                                    }
                                } else {
                                    ManagedMap innerlineitem = new ManagedMap();
                                    innerlineitemListChilds = DomUtils.getChildElementsByTagName(lineItemsChild, "inner-line-item");
                                    if (innerlineitemListChilds!= null) {
                                        if (innerlineitemListChilds.size() == 0) {
                                            innerlineitemListChilds = DomUtils.getChildElements(lineItemsChild);
                                        }
                                        for (Element innerlineitemChild: innerlineitemListChilds) {
                                            String innerlineitemValueRef = innerlineitemChild.getAttribute("value-ref");
                                            String innerlineitemKeyRef = innerlineitemChild.getAttribute("key-ref");
                                            Object valueObject = null;
                                            Object keyObject = null;
                                            if ((innerlineitemValueRef!= null)&&(!StringUtils.isBlank(innerlineitemValueRef))) {
                                                valueObject = new RuntimeBeanReference(innerlineitemValueRef);
                                            } else {
                                                valueObject = innerlineitemChild.getTextContent();
                                            }
                                            if ((innerlineitemKeyRef!= null)&&(!StringUtils.isBlank(innerlineitemKeyRef))) {
                                                keyObject = new RuntimeBeanReference(innerlineitemKeyRef);
                                            } else {
                                                keyObject = innerlineitemChild.getAttribute("key");
                                            }
                                            if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                                                keyObject = innerlineitemChild.getTagName();
                                            }
                                            innerlineitem.put(keyObject, valueObject);
                                        }
                                    }
                                    lineItems.add(innerlineitem);
                                }
                            }
                        }
                    }
                }
                builder.addPropertyValue("lineItems", lineItems);
            }
        }
        if ((element.getAttribute("documentNumber")!= null)&&(!StringUtils.isBlank(element.getAttribute("documentNumber")))) {
            builder.addPropertyValue("documentNumber", element.getAttribute("documentNumber"));
        }
        if ((element.getAttribute("postingDate")!= null)&&(!StringUtils.isBlank(element.getAttribute("postingDate")))) {
            builder.addPropertyValue("postingDate", element.getAttribute("postingDate"));
        }
        if ((element.getAttribute("locationCode")!= null)&&(!StringUtils.isBlank(element.getAttribute("locationCode")))) {
            builder.addPropertyValue("locationCode", element.getAttribute("locationCode"));
        }
        if ((element.getAttribute("returnAssistedParametersIndicator")!= null)&&(!StringUtils.isBlank(element.getAttribute("returnAssistedParametersIndicator")))) {
            builder.addPropertyValue("returnAssistedParametersIndicator", element.getAttribute("returnAssistedParametersIndicator"));
        }
        if ((element.getAttribute("returnGeneratedLineItemsIndicator")!= null)&&(!StringUtils.isBlank(element.getAttribute("returnGeneratedLineItemsIndicator")))) {
            builder.addPropertyValue("returnGeneratedLineItemsIndicator", element.getAttribute("returnGeneratedLineItemsIndicator"));
        }
        if (element.hasAttribute("deliveryTerm")) {
            builder.addPropertyValue("deliveryTerm", element.getAttribute("deliveryTerm"));
        }
        if ((element.getAttribute("documentDate")!= null)&&(!StringUtils.isBlank(element.getAttribute("documentDate")))) {
            builder.addPropertyValue("documentDate", element.getAttribute("documentDate"));
        }
        if ((element.getAttribute("transactionId")!= null)&&(!StringUtils.isBlank(element.getAttribute("transactionId")))) {
            builder.addPropertyValue("transactionId", element.getAttribute("transactionId"));
        }
        if ((element.getAttribute("postToJournal")!= null)&&(!StringUtils.isBlank(element.getAttribute("postToJournal")))) {
            builder.addPropertyValue("postToJournal", element.getAttribute("postToJournal"));
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
