
package org.mule.modules.vertex.config.spring;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.modules.vertex.config.FindTaxAreasMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.support.ManagedMap;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.xml.DomUtils;
import org.w3c.dom.Element;

public class FindTaxAreasDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public FindTaxAreasDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(FindTaxAreasMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        Element taxAreaLookupsListElement = null;
        taxAreaLookupsListElement = DomUtils.getChildElementByTagName(element, "tax-area-lookups");
        List<Element> taxAreaLookupsListChilds = null;
        if (taxAreaLookupsListElement!= null) {
            String taxAreaLookupsRef = taxAreaLookupsListElement.getAttribute("ref");
            if ((taxAreaLookupsRef!= null)&&(!StringUtils.isBlank(taxAreaLookupsRef))) {
                if ((!taxAreaLookupsRef.startsWith(patternInfo.getPrefix()))&&(!taxAreaLookupsRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("taxAreaLookups", new RuntimeBeanReference(taxAreaLookupsRef));
                } else {
                    builder.addPropertyValue("taxAreaLookups", taxAreaLookupsRef);
                }
            } else {
                ManagedList taxAreaLookups = new ManagedList();
                taxAreaLookupsListChilds = DomUtils.getChildElementsByTagName(taxAreaLookupsListElement, "tax-area-lookup");
                if (taxAreaLookupsListChilds!= null) {
                    for (Element taxAreaLookupsChild: taxAreaLookupsListChilds) {
                        String valueRef = taxAreaLookupsChild.getAttribute("value-ref");
                        if ((valueRef!= null)&&(!StringUtils.isBlank(valueRef))) {
                            taxAreaLookups.add(new RuntimeBeanReference(valueRef));
                        } else {
                            List<Element> innertaxarealookupListChilds = null;
                            if (taxAreaLookupsChild!= null) {
                                String innertaxarealookupRef = taxAreaLookupsChild.getAttribute("ref");
                                if ((innertaxarealookupRef!= null)&&(!StringUtils.isBlank(innertaxarealookupRef))) {
                                    if ((!innertaxarealookupRef.startsWith(patternInfo.getPrefix()))&&(!innertaxarealookupRef.endsWith(patternInfo.getSuffix()))) {
                                        builder.addPropertyValue("inner-tax-area-lookup", new RuntimeBeanReference(innertaxarealookupRef));
                                    } else {
                                        builder.addPropertyValue("inner-tax-area-lookup", innertaxarealookupRef);
                                    }
                                } else {
                                    ManagedMap innertaxarealookup = new ManagedMap();
                                    innertaxarealookupListChilds = DomUtils.getChildElementsByTagName(taxAreaLookupsChild, "inner-tax-area-lookup");
                                    if (innertaxarealookupListChilds!= null) {
                                        if (innertaxarealookupListChilds.size() == 0) {
                                            innertaxarealookupListChilds = DomUtils.getChildElements(taxAreaLookupsChild);
                                        }
                                        for (Element innertaxarealookupChild: innertaxarealookupListChilds) {
                                            String innertaxarealookupValueRef = innertaxarealookupChild.getAttribute("value-ref");
                                            String innertaxarealookupKeyRef = innertaxarealookupChild.getAttribute("key-ref");
                                            Object valueObject = null;
                                            Object keyObject = null;
                                            if ((innertaxarealookupValueRef!= null)&&(!StringUtils.isBlank(innertaxarealookupValueRef))) {
                                                valueObject = new RuntimeBeanReference(innertaxarealookupValueRef);
                                            } else {
                                                valueObject = innertaxarealookupChild.getTextContent();
                                            }
                                            if ((innertaxarealookupKeyRef!= null)&&(!StringUtils.isBlank(innertaxarealookupKeyRef))) {
                                                keyObject = new RuntimeBeanReference(innertaxarealookupKeyRef);
                                            } else {
                                                keyObject = innertaxarealookupChild.getAttribute("key");
                                            }
                                            if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                                                keyObject = innertaxarealookupChild.getTagName();
                                            }
                                            innertaxarealookup.put(keyObject, valueObject);
                                        }
                                    }
                                    taxAreaLookups.add(innertaxarealookup);
                                }
                            }
                        }
                    }
                }
                builder.addPropertyValue("taxAreaLookups", taxAreaLookups);
            }
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
