
package org.mule.modules.vertex.config.spring;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.modules.vertex.config.IsTaxAreaChangedMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.support.ManagedMap;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.xml.DomUtils;
import org.w3c.dom.Element;

public class IsTaxAreaChangedDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public IsTaxAreaChangedDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(IsTaxAreaChangedMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        Element datePeriodListElement = null;
        datePeriodListElement = DomUtils.getChildElementByTagName(element, "date-period");
        List<Element> datePeriodListChilds = null;
        if (datePeriodListElement!= null) {
            String datePeriodRef = datePeriodListElement.getAttribute("ref");
            if ((datePeriodRef!= null)&&(!StringUtils.isBlank(datePeriodRef))) {
                if ((!datePeriodRef.startsWith(patternInfo.getPrefix()))&&(!datePeriodRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("datePeriod", new RuntimeBeanReference(datePeriodRef));
                } else {
                    builder.addPropertyValue("datePeriod", datePeriodRef);
                }
            } else {
                ManagedMap datePeriod = new ManagedMap();
                datePeriodListChilds = DomUtils.getChildElementsByTagName(datePeriodListElement, "date-period");
                if (datePeriodListChilds!= null) {
                    if (datePeriodListChilds.size() == 0) {
                        datePeriodListChilds = DomUtils.getChildElements(datePeriodListElement);
                    }
                    for (Element datePeriodChild: datePeriodListChilds) {
                        String datePeriodValueRef = datePeriodChild.getAttribute("value-ref");
                        String datePeriodKeyRef = datePeriodChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((datePeriodValueRef!= null)&&(!StringUtils.isBlank(datePeriodValueRef))) {
                            valueObject = new RuntimeBeanReference(datePeriodValueRef);
                        } else {
                            valueObject = datePeriodChild.getTextContent();
                        }
                        if ((datePeriodKeyRef!= null)&&(!StringUtils.isBlank(datePeriodKeyRef))) {
                            keyObject = new RuntimeBeanReference(datePeriodKeyRef);
                        } else {
                            keyObject = datePeriodChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = datePeriodChild.getTagName();
                        }
                        datePeriod.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("datePeriod", datePeriod);
            }
        }
        if ((element.getAttribute("taxAreaId-ref")!= null)&&(!StringUtils.isBlank(element.getAttribute("taxAreaId-ref")))) {
            if (element.getAttribute("taxAreaId-ref").startsWith("#")) {
                builder.addPropertyValue("taxAreaId", element.getAttribute("taxAreaId-ref"));
            } else {
                builder.addPropertyValue("taxAreaId", (("#[registry:"+ element.getAttribute("taxAreaId-ref"))+"]"));
            }
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
