
package org.mule.modules.vertex.config.spring;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.modules.vertex.config.TaxAreaLookupMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.support.ManagedMap;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.xml.DomUtils;
import org.w3c.dom.Element;

public class TaxAreaLookupDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public TaxAreaLookupDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(TaxAreaLookupMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        Element taxAreaLookupListElement = null;
        taxAreaLookupListElement = DomUtils.getChildElementByTagName(element, "tax-area-lookup");
        List<Element> taxAreaLookupListChilds = null;
        if (taxAreaLookupListElement!= null) {
            String taxAreaLookupRef = taxAreaLookupListElement.getAttribute("ref");
            if ((taxAreaLookupRef!= null)&&(!StringUtils.isBlank(taxAreaLookupRef))) {
                if ((!taxAreaLookupRef.startsWith(patternInfo.getPrefix()))&&(!taxAreaLookupRef.endsWith(patternInfo.getSuffix()))) {
                    builder.addPropertyValue("taxAreaLookup", new RuntimeBeanReference(taxAreaLookupRef));
                } else {
                    builder.addPropertyValue("taxAreaLookup", taxAreaLookupRef);
                }
            } else {
                ManagedMap taxAreaLookup = new ManagedMap();
                taxAreaLookupListChilds = DomUtils.getChildElementsByTagName(taxAreaLookupListElement, "tax-area-lookup");
                if (taxAreaLookupListChilds!= null) {
                    if (taxAreaLookupListChilds.size() == 0) {
                        taxAreaLookupListChilds = DomUtils.getChildElements(taxAreaLookupListElement);
                    }
                    for (Element taxAreaLookupChild: taxAreaLookupListChilds) {
                        String taxAreaLookupValueRef = taxAreaLookupChild.getAttribute("value-ref");
                        String taxAreaLookupKeyRef = taxAreaLookupChild.getAttribute("key-ref");
                        Object valueObject = null;
                        Object keyObject = null;
                        if ((taxAreaLookupValueRef!= null)&&(!StringUtils.isBlank(taxAreaLookupValueRef))) {
                            valueObject = new RuntimeBeanReference(taxAreaLookupValueRef);
                        } else {
                            valueObject = taxAreaLookupChild.getTextContent();
                        }
                        if ((taxAreaLookupKeyRef!= null)&&(!StringUtils.isBlank(taxAreaLookupKeyRef))) {
                            keyObject = new RuntimeBeanReference(taxAreaLookupKeyRef);
                        } else {
                            keyObject = taxAreaLookupChild.getAttribute("key");
                        }
                        if ((keyObject == null)||((keyObject instanceof String)&&StringUtils.isBlank(((String) keyObject)))) {
                            keyObject = taxAreaLookupChild.getTagName();
                        }
                        taxAreaLookup.put(keyObject, valueObject);
                    }
                }
                builder.addPropertyValue("taxAreaLookup", taxAreaLookup);
            }
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
